@@ -42,6 +42,7 @@ use Data::Dumper;
 use Carp;
 
 use Xacobeo::Utils qw(:dom);
+use Xacobeo::I18n;
 
 
 use base qw(Class::Accessor::Fast);
@@ -81,24 +82,27 @@ sub new {
 
 Runs the given XPath query on the document and returns the results. The results
 could be a node list or a single value like a boolean, a number or a scalar if
-an expression is passed.
+an expression is passed. This method always return its values in scalar context.
+
+This method croaks if the expression can't be evaluated.
 
 Parameters:
 
-	$xpath: a valid XPath expression.
+	$xpath: the XPath expression to execute.
 
 =cut
 
 sub find {
 	my $self = shift;
 	my ($xpath) = @_;
+	croak __("Document node is missing") unless defined $self->xml;
 	
 	my $result;
 	eval {
 		$result = $self->xpath->find($xpath, $self->xml);
 	};
 	if (my $error = $@) {
-		return;
+		croak $error;
 	}
 	
 	return $result;
@@ -111,9 +115,12 @@ Validates the syntax of the given XPath query. The syntax is validated within a
 context that has the same namespaces as the ones defined in the current XML
 document.
 
+B<NOTE>: This method can't validate if undefined functions or variables are
+used.
+
 Parameters:
 
-	$xpath: a valid XPath expression.
+	$xpath: the XPath expression to validate.
 
 =cut
 
@@ -237,9 +244,11 @@ sub _get_all_namespaces {
 	my %namespaces = (
 		XML_XML_NS() => 'xml',
 	);
-	foreach my $namespace ($node->findnodes('.//namespace::*')) {
-		my $uri = $namespace->getData;
-		$namespaces{$uri} ||= $namespace->getLocalName;
+	if ($node) {
+		foreach my $namespace ($node->findnodes('.//namespace::*')) {
+			my $uri = $namespace->getData;
+			$namespaces{$uri} ||= $namespace->getLocalName;
+		}
 	}
 	
 	# Reverse the namespaces ($prefix -> $uri) and make sure that the prefixes
